"""Re-usable plot components.

This module contains several re-usable plot components that contain the data for a
Plotly (sub) figure. See :obj:`~ragraph.plot.generic.Component` for the definition of a
plot component.
"""

from ragraph.plot.components.blank import Blank  # noqa
from ragraph.plot.components.labels import Labels  # noqa
from ragraph.plot.components.legend import Legend  # noqa
from ragraph.plot.components.piemap import PieMap  # noqa
from ragraph.plot.components.tree import Tree  # noqa
